@@ -1,6 +1,7 @@
 """Simple report components."""
 
 import argparse
+import json
 import os
 
 import pandas as pd
@@ -53,12 +54,45 @@ def version_table(versions, header=_version_header, report=None):
     return report
 
 
+_params_header = """
+### Workflow parameters
+
+The table below highlights values of the main parameters used in this analysis.
+"""
+
+
+def params_table(params, header=_params_header, report=None):
+    """Create a workflow parameter report from a JSON file.
+
+    :param versions: Flat JSON file containing key, value pairs
+        corresponding to workflow parameter 'key/name,value' pairs.
+    :param header: a markdown formatted header.
+    :param report: an HTMLSection instance.
+
+    :returns: an HTMLSection instance, if `report` was provided the given
+        instance is modified and returned.
+    """
+    report = _maybe_new_report(report)
+    report.markdown(header)
+
+    if not os.path.isfile(params):
+        raise IOError('`params` should be a JSON file.')
+
+    with open(params) as f:
+        data = json.load(f)
+        params = [(k, v) for k, v in data.items()]
+        df_params = pd.DataFrame(params, columns=['Key', 'Value'])
+        report.table(df_params, index=False)
+        return report
+
+
 def main(args):
     """Entry point to create demo report of functionality in this module."""
     report = HTMLReport(
         title="Simple component demo.",
         lead="A demonstration of small, simple reporting components.")
     report.add_section(section=version_table(args.versions))
+    report.add_section(section=params_table(args.params))
     report.write(args.output)
 
 
@@ -73,6 +107,11 @@ def argparser():
         help=(
             "Headerless CSV containing 'software,version', "
             "or directory of such files."))
+    parser.add_argument(
+        "--params",
+        help=(
+            "A JSON file containing the workflow parameter "
+            "key/values."))
     parser.add_argument(
         "--output", default="simple_components_report.html",
         help="Output HTML file.")
